@@ -13,19 +13,23 @@ Usage::
     client: OpenSearchServiceServerlessClient = session.client("opensearchserverless")
     ```
 """
+
 import sys
 from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import CollectionTypeType, SecurityPolicyTypeType
+from .literals import CollectionTypeType, SecurityPolicyTypeType, StandbyReplicasType
 from .type_defs import (
     BatchGetCollectionResponseTypeDef,
+    BatchGetEffectiveLifecyclePolicyResponseTypeDef,
+    BatchGetLifecyclePolicyResponseTypeDef,
     BatchGetVpcEndpointResponseTypeDef,
     CapacityLimitsTypeDef,
     CollectionFiltersTypeDef,
     CreateAccessPolicyResponseTypeDef,
     CreateCollectionResponseTypeDef,
+    CreateLifecyclePolicyResponseTypeDef,
     CreateSecurityConfigResponseTypeDef,
     CreateSecurityPolicyResponseTypeDef,
     CreateVpcEndpointResponseTypeDef,
@@ -36,8 +40,11 @@ from .type_defs import (
     GetPoliciesStatsResponseTypeDef,
     GetSecurityConfigResponseTypeDef,
     GetSecurityPolicyResponseTypeDef,
+    LifecyclePolicyIdentifierTypeDef,
+    LifecyclePolicyResourceIdentifierTypeDef,
     ListAccessPoliciesResponseTypeDef,
     ListCollectionsResponseTypeDef,
+    ListLifecyclePoliciesResponseTypeDef,
     ListSecurityConfigsResponseTypeDef,
     ListSecurityPoliciesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
@@ -47,13 +54,14 @@ from .type_defs import (
     UpdateAccessPolicyResponseTypeDef,
     UpdateAccountSettingsResponseTypeDef,
     UpdateCollectionResponseTypeDef,
+    UpdateLifecyclePolicyResponseTypeDef,
     UpdateSecurityConfigResponseTypeDef,
     UpdateSecurityPolicyResponseTypeDef,
     UpdateVpcEndpointResponseTypeDef,
     VpcEndpointFiltersTypeDef,
 )
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -62,7 +70,7 @@ else:
 __all__ = ("OpenSearchServiceServerlessClient",)
 
 
-class BotocoreClientError(BaseException):
+class BotocoreClientError(Exception):
     MSG_TEMPLATE: str
 
     def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
@@ -74,7 +82,9 @@ class Exceptions:
     ClientError: Type[BotocoreClientError]
     ConflictException: Type[BotocoreClientError]
     InternalServerException: Type[BotocoreClientError]
+    OcuLimitExceededException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
+    ServiceQuotaExceededException: Type[BotocoreClientError]
     ValidationException: Type[BotocoreClientError]
 
 
@@ -100,12 +110,35 @@ class OpenSearchServiceServerlessClient(BaseClient):
     ) -> BatchGetCollectionResponseTypeDef:
         """
         Returns attributes for one or more collections, including the collection
-        endpoint and the OpenSearch Dashboards endpoint.
+        endpoint and the OpenSearch Dashboards
+        endpoint.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.batch_get_collection)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#batch_get_collection)
         """
 
+    def batch_get_effective_lifecycle_policy(
+        self, *, resourceIdentifiers: Sequence[LifecyclePolicyResourceIdentifierTypeDef]
+    ) -> BatchGetEffectiveLifecyclePolicyResponseTypeDef:
+        """
+        Returns a list of successful and failed retrievals for the OpenSearch
+        Serverless
+        indexes.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.batch_get_effective_lifecycle_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#batch_get_effective_lifecycle_policy)
+        """
+
+    def batch_get_lifecycle_policy(
+        self, *, identifiers: Sequence[LifecyclePolicyIdentifierTypeDef]
+    ) -> BatchGetLifecyclePolicyResponseTypeDef:
+        """
+        Returns one or more configured OpenSearch Serverless lifecycle policies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.batch_get_lifecycle_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#batch_get_lifecycle_policy)
+        """
+
     def batch_get_vpc_endpoint(self, *, ids: Sequence[str]) -> BatchGetVpcEndpointResponseTypeDef:
         """
         Returns attributes for one or more VPC endpoints associated with the current
@@ -153,6 +186,7 @@ class OpenSearchServiceServerlessClient(BaseClient):
         name: str,
         clientToken: str = ...,
         description: str = ...,
+        standbyReplicas: StandbyReplicasType = ...,
         tags: Sequence[TagTypeDef] = ...,
         type: CollectionTypeType = ...
     ) -> CreateCollectionResponseTypeDef:
@@ -163,6 +197,22 @@ class OpenSearchServiceServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#create_collection)
         """
 
+    def create_lifecycle_policy(
+        self,
+        *,
+        name: str,
+        policy: str,
+        type: Literal["retention"],
+        clientToken: str = ...,
+        description: str = ...
+    ) -> CreateLifecyclePolicyResponseTypeDef:
+        """
+        Creates a lifecyle policy to be applied to OpenSearch Serverless indexes.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.create_lifecycle_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#create_lifecycle_policy)
+        """
+
     def create_security_config(
         self,
         *,
@@ -232,6 +282,16 @@ class OpenSearchServiceServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#delete_collection)
         """
 
+    def delete_lifecycle_policy(
+        self, *, name: str, type: Literal["retention"], clientToken: str = ...
+    ) -> Dict[str, Any]:
+        """
+        Deletes an OpenSearch Serverless lifecycle policy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.delete_lifecycle_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#delete_lifecycle_policy)
+        """
+
     def delete_security_config(self, *, id: str, clientToken: str = ...) -> Dict[str, Any]:
         """
         Deletes a security configuration for OpenSearch Serverless.
@@ -295,7 +355,8 @@ class OpenSearchServiceServerlessClient(BaseClient):
     def get_policies_stats(self) -> GetPoliciesStatsResponseTypeDef:
         """
         Returns statistical information about your OpenSearch Serverless access
-        policies, security configurations, and security policies.
+        policies, security configurations, and security
+        policies.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.get_policies_stats)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#get_policies_stats)
@@ -348,6 +409,21 @@ class OpenSearchServiceServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#list_collections)
         """
 
+    def list_lifecycle_policies(
+        self,
+        *,
+        type: Literal["retention"],
+        maxResults: int = ...,
+        nextToken: str = ...,
+        resources: Sequence[str] = ...
+    ) -> ListLifecyclePoliciesResponseTypeDef:
+        """
+        Returns a list of OpenSearch Serverless lifecycle policies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.list_lifecycle_policies)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#list_lifecycle_policies)
+        """
+
     def list_security_configs(
         self, *, type: Literal["saml"], maxResults: int = ..., nextToken: str = ...
     ) -> ListSecurityConfigsResponseTypeDef:
@@ -391,7 +467,8 @@ class OpenSearchServiceServerlessClient(BaseClient):
     ) -> ListVpcEndpointsResponseTypeDef:
         """
         Returns the OpenSearch Serverless-managed interface VPC endpoints associated
-        with the current account.
+        with the current
+        account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.list_vpc_endpoints)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#list_vpc_endpoints)
@@ -451,6 +528,23 @@ class OpenSearchServiceServerlessClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#update_collection)
         """
 
+    def update_lifecycle_policy(
+        self,
+        *,
+        name: str,
+        policyVersion: str,
+        type: Literal["retention"],
+        clientToken: str = ...,
+        description: str = ...,
+        policy: str = ...
+    ) -> UpdateLifecyclePolicyResponseTypeDef:
+        """
+        Updates an OpenSearch Serverless access policy.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/opensearchserverless.html#OpenSearchServiceServerless.Client.update_lifecycle_policy)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearchserverless/client/#update_lifecycle_policy)
+        """
+
     def update_security_config(
         self,
         *,
